# German Discourse networks
# Euro Crisis and Europe's Migration Crisis
# 2010-15

set.seed(7)

# setwd("")

## load the data & package

GER_EC_data <- read.csv("00_replication_material_EC_GER2010_15.csv", sep=";")
summary(GER_EC_data)
GER_MC_data <- read.csv("00_replication_material_MC_GER2010_15.csv", sep=";")
summary(GER_MC_data)

library(igraph)

windowsFonts("Times" = windowsFont("Times"))
windowsFonts("Helvetica" = windowsFont("Helvetica"))

#attributing vertex colors, shapes and font type
col <- c("white", "grey75")
shape <- c("circle", "square")
let <- c("Times", "Helvetica")

# using subset function to select justification & justification scope
GER_EC_data1015 <- subset(GER_EC_data, select=c(justification, parties))
GER_MC_data1015 <- subset(GER_MC_data, select=c(justification, parties))

# creating graphs
GER_EC_g1015 <- graph.data.frame(GER_EC_data1015, directed = FALSE)
GER_EC_g1015
GER_MC_g1015 <- graph.data.frame(GER_MC_data1015, directed = FALSE)
GER_MC_g1015

# creating bipartite network - graph object recognises two different nodes now
V(GER_EC_g1015)$type <- FALSE
V(GER_EC_g1015)$type[V(GER_EC_g1015)$name %in% GER_EC_data1015[, 1]] <- TRUE
V(GER_MC_g1015)$type <- FALSE
V(GER_MC_g1015)$type[V(GER_MC_g1015)$name %in% GER_MC_data1015[, 1]] <- TRUE

# delete 'no justification' vertices
GER_EC_g1015nj <- delete_vertices(GER_EC_g1015, c("no justification", "no party affiliation"))
GER_MC_g1015nj <- delete_vertices(GER_MC_g1015, c("no justification", "no party affiliation"))

# summing up multiple edges between two nodes
E(GER_EC_g1015nj)$weight <- 1
GER_EC_g1015njw <- simplify(GER_EC_g1015nj, edge.attr.comb = list(weight="sum"))
E(GER_MC_g1015nj)$weight <- 1
GER_MC_g1015njw <- simplify(GER_MC_g1015nj, edge.attr.comb = list(weight="sum"))

# delete edge weight below 2/3
GER_EC_g1015njw <- delete_edges(GER_EC_g1015njw, E(GER_EC_g1015njw)[weight<2]) 
GER_MC_g1015njw <- delete_edges(GER_MC_g1015njw, E(GER_MC_g1015njw)[weight<3])

# delete vertices with degree centrality below 1 
EC_deg <- degree(GER_EC_g1015njw, normalized = F)
EC_bad.vs<-V(GER_EC_g1015njw)[EC_deg<1]
GER_EC_g1015njwv <- delete.vertices(GER_EC_g1015njw, EC_bad.vs)
MC_deg <- degree(GER_MC_g1015njw, normalized = F)
MC_bad.vs<-V(GER_MC_g1015njw)[MC_deg<1]
GER_MC_g1015njwv <- delete.vertices(GER_MC_g1015njw, MC_bad.vs)

sum(E(GER_EC_g1015njwv)$weight)
sum(E(GER_MC_g1015njwv)$weight)

# eigenvector centrality
GER1015_EC_eig <- evcent(GER_EC_g1015njwv)
GER1015_MC_eig <- evcent(GER_MC_g1015njwv)
sort(GER1015_EC_eig$vector, decreasing = T)
sort(GER1015_MC_eig$vector, decreasing = T)

# normalised degree centrality
GER1015_EC_deg <- degree(GER_EC_g1015njwv, normalized = T)
GER1015_MC_deg <- degree(GER_MC_g1015njwv, normalized = T)
sort(GER1015_EC_deg, decreasing = T)
sort(GER1015_MC_deg, decreasing = T)

# mean degree centrality as indirect measurement of network density
mean(degree(GER_EC_g1015njwv))
mean(degree(GER_MC_g1015njwv))

# network centralisatrion
centralization.evcent(GER_EC_g1015njwv)
centralization.evcent(GER_MC_g1015njwv)

# plotting discourse network 2010-2015
# Figure 2
tiff("00_Figure02.tif", res= 600, compression = "lzw", height = 7, width = 7, units = "in")
par(mfrow=c(1,1), mar=c(0, 0, 0, 0))
plot(GER_EC_g1015njwv, layout = layout_nicely,
     vertex.size = sqrt((GER1015_EC_eig$vector+0.1)*50),
     vertex.color = col[as.numeric(V(GER_EC_g1015njwv)$type) +1],
     vertex.label.degree=pi/2,
     vertex.label.dist=0.1,
     vertex.label.font=1,
     vertex.label.family= let[as.numeric(V(GER_EC_g1015njwv)$type) + 1],
     vertex.label.cex= sqrt((GER1015_EC_eig$vector+0.2)*1.5),
     vertex.label.color= 'black',
     vertex.frame.color	= 'grey75',
     vertex.shape = shape[as.numeric(V(GER_EC_g1015njwv)$type) + 1],
     edge.width= (E(GER_EC_g1015njwv)$weight),
     edge.color = "grey90"
     )
#title(main = list("Figure 2: Euro Crisis, 2010-15", cex=1.1))
dev.off()

# Figure 3
tiff("00_Figure03.tif", res= 600, compression = "lzw", height = 7, width = 7, units = "in")
par(mfrow=c(1,1), mar=c(0, 0, 0, 0))
plot(GER_MC_g1015njwv, layout = layout_nicely,
     vertex.size = sqrt((GER1015_MC_eig$vector+0.1)*50),
     vertex.color = col[as.numeric(V(GER_MC_g1015njwv)$type) +1],
     vertex.label.degree=pi/2,
     vertex.label.dist=0.1,
     vertex.label.font=1,
     vertex.label.family= let[as.numeric(V(GER_MC_g1015njwv)$type) + 1],
     vertex.label.cex= sqrt((GER1015_MC_eig$vector+0.2)*1.5),
     vertex.label.color= 'black',
     vertex.frame.color	= 'grey75',
     vertex.shape = shape[as.numeric(V(GER_MC_g1015njwv)$type) + 1],
     edge.width= (E(GER_MC_g1015njwv)$weight),
     edge.color = "grey90"
     )
#title(main = "Figure 3: Europe's migration crisis, 2010-15", cex=1.1)
dev.off()


# Multiple Line Chart
# Figure 01

data <- read.csv("00_replication_material_GER_EC_MC.csv", sep=";")

tiff("00_Figure01.tif", res= 600, compression = "lzw", height = 3, width = 5, units = "in")
par(mfrow=c(1,1), mar=c(4, 4, 1, 1))
plot(data$year, data$SZ_MC, type="o", col="black", axes=T, ann=F, ylim = c(0,220), lwd=1)
box()
lines(data$year, data$Welt_MC, type="o", pch=22, lty=2, col="black", lwd= 1)
lines(data$year, data$SZ_EC, type="o", pch=21, lty=1, col="grey45", lwd=1)
lines(data$year, data$Welt_EC, type="o", pch=22, lty=2, col="grey45", lwd=1)
title(xlab="year")
title(ylab="frequency of claims")
legend("topleft", c("SZ (migration crisis)","Welt (migration crisis)", "SZ (Euro crisis)", "Welt (Euro crisis)"), cex=0.6, 
       col=c("black","black", "grey45", "grey45"), pch=21:22, lty=1:2, lwd=1)
#title(main = list("Figure 1: number of claims in Europe's migration crisis and in the Euro crisis", cex=1.1))
dev.off()
